# WooCommerce ExciteSMS Notifications

A WooCommerce extension to send SMS notifications using ExciteSMS.

## Description

This plugin allows you to send SMS notifications to your customers using the ExciteSMS gateway. Notifications can be sent for new orders and order status changes. Customize your SMS templates using placeholders for order details.

## Features

- Send SMS notifications for new orders.
- Send SMS notifications for order status changes.
- Customize SMS templates with placeholders.
- Easy setup and configuration.

## Installation

1. Download the plugin files and upload them to the `/wp-content/plugins/woocommerce-excitesms-notifications` directory, or install the plugin through the WordPress plugins screen directly.
2. Activate the plugin through the 'Plugins' screen in WordPress.
3. Navigate to `Settings` -> `ExciteSMS Notifications` to configure the plugin.

## Configuration

1. **API Key**: Enter your ExciteSMS API key.
2. **Sender ID**: Enter your ExciteSMS sender ID.
3. **SMS Templates**: Customize your SMS templates for new orders and order status changes.

### SMS Template Placeholders

- `{order_number}`: The order number.
- `{order_date}`: The date and time the order was placed.
- `{billing_first_name}`: The customer's billing first name.
- `{billing_last_name}`: The customer's billing last name.
- `{billing_email}`: The customer's billing email.
- `{new_status}`: The new status of the order (for status change notifications).

### Example Templates

- **New Order Template**:
  ```
  Thank you for your order. Your order number is {order_number}.
  ```

- **Order Status Changed Template**:
  ```
  Your order #{order_number} status changed to {new_status}.
  ```

## Usage

### Sending SMS for New Orders

The plugin sends an SMS notification to the customer's billing phone number when a new order is placed. The SMS content is based on the template configured in the settings.

### Sending SMS for Order Status Changes

The plugin sends an SMS notification to the customer's billing phone number when an order status changes. The SMS content is based on the template configured in the settings.

## Debugging

If you encounter issues with the plugin, you can enable debugging in WordPress to check for errors.

1. Edit your `wp-config.php` file and add the following lines to enable debugging:
   ```php
   define( 'WP_DEBUG', true );
   define( 'WP_DEBUG_LOG', true );
   ```

2. Check the `wp-content/debug.log` file for error messages related to the plugin.

## Contributing

1. Fork the repository.
2. Create your feature branch (`git checkout -b feature/AmazingFeature`).
3. Commit your changes (`git commit -m 'Add some AmazingFeature'`).
4. Push to the branch (`git push origin feature/AmazingFeature`).
5. Open a pull request.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## Acknowledgements

- [WooCommerce](https://woocommerce.com/) - E-commerce plugin for WordPress.
- [ExciteSMS](https://excitesms.com/) - SMS gateway service.

---

**Author**: Kazashim Kuzasuwat

**Version**: 1.0


### How to Use the `README.md`

1. **Create a New Repository**:
   - Go to GitHub and create a new repository named `woocommerce-excitesms-notifications`.

2. **Add Files to the Repository**:
   - Clone your new repository to your local machine.
   - Copy your plugin files (`woocommerce-excitesms-notifications.php` and the `includes` folder) into the cloned repository folder.

3. **Create the `README.md`**:
   - In the repository folder, create a new file named `README.md`.
   - Copy the provided README content into this file.

4. **Commit and Push**:
   - Commit all files to your repository:
     ```bash
     git add .
     git commit -m "Initial commit"
     git push origin main
     ```
