<?php

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class WC_ExciteSMS {

    public function __construct() {
        // Add settings menu
        add_action( 'admin_menu', array( $this, 'add_settings_page' ) );
        add_action( 'admin_menu', array( $this, 'add_log_page' ) );
        // Register settings
        add_action( 'admin_init', array( $this, 'register_settings' ) );
        // WooCommerce hooks
        add_action( 'woocommerce_thankyou', array( $this, 'send_sms_new_order' ) );
        add_action( 'woocommerce_order_status_changed', array( $this, 'send_sms_order_status_changed' ), 10, 3 );
        add_action( 'woocommerce_order_status_cancelled', array( $this, 'send_sms_order_cancelled' ) );
        // Enqueue admin styles
        add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_styles' ) );
    }

    public function add_settings_page() {
        add_options_page(
            'WooCommerce ExciteSMS Notifications',
            'ExciteSMS Notifications',
            'manage_options',
            'wc-excitesms',
            array( $this, 'settings_page' )
        );
    }

    public function add_log_page() {
        add_menu_page(
            'ExciteSMS Log',
            'ExciteSMS Log',
            'manage_options',
            'wc-excitesms-log',
            array( $this, 'log_page' ),
            'dashicons-list-view',
            65
        );
    }

    public function settings_page() {
        ?>
        <div class="wrap">
            <h1>WooCommerce ExciteSMS Notifications</h1>
            <form method="post" action="options.php">
                <?php
                settings_fields( 'wc_excitesms_settings' );
                do_settings_sections( 'wc-excitesms' );
                submit_button();
                ?>
            </form>
        </div>
        <?php
    }

    public function log_page() {
        ?>
        <div class="wrap">
            <h1>ExciteSMS Log</h1>
            <?php
            $log = get_option( 'wc_excitesms_log', array() );

            if ( empty( $log ) ) {
                echo '<p>No logs available.</p>';
            } else {
                echo '<table class="widefat fixed" cellspacing="0">';
                echo '<thead>';
                echo '<tr>';
                echo '<th>Recipient</th>';
                echo '<th>Message</th>';
                echo '<th>Response</th>';
                echo '<th>Date</th>';
                echo '</tr>';
                echo '</thead>';
                echo '<tbody>';

                foreach ( array_reverse( $log ) as $entry ) {
                    echo '<tr>';
                    echo '<td>' . esc_html( $entry['recipient'] ) . '</td>';
                    echo '<td>' . esc_html( $entry['message'] ) . '</td>';
                    echo '<td>' . esc_html( json_encode( $entry['response'] ) ) . '</td>';
                    echo '<td>' . esc_html( date( 'Y-m-d H:i:s', strtotime( $entry['date'] ) ) ) . '</td>';
                    echo '</tr>';
                }

                echo '</tbody>';
                echo '</table>';
            }
            ?>
        </div>
        <?php
    }

    public function register_settings() {
        register_setting( 'wc_excitesms_settings', 'wc_excitesms_api_key' );
        register_setting( 'wc_excitesms_settings', 'wc_excitesms_sender_id' );
        register_setting( 'wc_excitesms_settings', 'wc_excitesms_templates' );
        register_setting( 'wc_excitesms_settings', 'wc_excitesms_seller_phone' );
        register_setting( 'wc_excitesms_settings', 'wc_excitesms_enabled_notifications', array(
            'default' => array(
                'new_order' => true,
                'order_status_changed' => true,
                'order_cancelled' => true,
            )
        ) );

        add_settings_section(
            'wc_excitesms_section',
            'ExciteSMS Settings',
            null,
            'wc-excitesms'
        );

        add_settings_field(
            'wc_excitesms_api_key',
            'API Key',
            array( $this, 'api_key_field' ),
            'wc-excitesms',
            'wc_excitesms_section'
        );

        add_settings_field(
            'wc_excitesms_sender_id',
            'Sender ID',
            array( $this, 'sender_id_field' ),
            'wc-excitesms',
            'wc_excitesms_section'
        );

        add_settings_field(
            'wc_excitesms_seller_phone',
            'Seller Phone Number',
            array( $this, 'seller_phone_field' ),
            'wc-excitesms',
            'wc_excitesms_section'
        );

        add_settings_field(
            'wc_excitesms_templates',
            'SMS Templates',
            array( $this, 'templates_field' ),
            'wc-excitesms',
            'wc_excitesms_section'
        );

        add_settings_field(
            'wc_excitesms_enabled_notifications',
            'Enabled Notifications',
            array( $this, 'enabled_notifications_field' ),
            'wc-excitesms',
            'wc_excitesms_section'
        );
    }

    public function api_key_field() {
        $api_key = get_option( 'wc_excitesms_api_key' );
        echo '<input type="text" name="wc_excitesms_api_key" value="' . esc_attr( $api_key ) . '" class="regular-text">';
    }

    public function sender_id_field() {
        $sender_id = get_option( 'wc_excitesms_sender_id' );
        echo '<input type="text" name="wc_excitesms_sender_id" value="' . esc_attr( $sender_id ) . '" class="regular-text">';
    }

    public function seller_phone_field() {
        $seller_phone = get_option( 'wc_excitesms_seller_phone' );
        echo '<input type="text" name="wc_excitesms_seller_phone" value="' . esc_attr( $seller_phone ) . '" class="regular-text">';
    }

    public function templates_field() {
        $templates = get_option( 'wc_excitesms_templates', array() );
        ?>
        <table class="form-table">
            <thead>
                <tr>
                    <th>Event</th>
                    <th>Template</th>
                </tr>
            </thead>
            <tbody>
                <tr>
                    <td>New Order</td>
                    <td><textarea name="wc_excitesms_templates[new_order]" class="large-text"><?php echo esc_textarea( $templates['new_order'] ?? '' ); ?></textarea></td>
                </tr>
                <tr>
                    <td>Order Status Changed</td>
                    <td><textarea name="wc_excitesms_templates[order_status_changed]" class="large-text"><?php echo esc_textarea( $templates['order_status_changed'] ?? '' ); ?></textarea></td>
                </tr>
                <tr>
                    <td>Order Cancelled</td>
                    <td><textarea name="wc_excitesms_templates[order_cancelled]" class="large-text"><?php echo esc_textarea( $templates['order_cancelled'] ?? '' ); ?></textarea></td>
                </tr>
            </tbody>
        </table>
        <?php
    }

    public function enabled_notifications_field() {
        $enabled_notifications = get_option( 'wc_excitesms_enabled_notifications', array() );
        ?>
        <label>
            <input type="checkbox" name="wc_excitesms_enabled_notifications[new_order]" value="1" <?php checked( 1, isset( $enabled_notifications['new_order'] ) ? $enabled_notifications['new_order'] : 0 ); ?>>
            Enable New Order Notification
        </label><br>
        <label>
            <input type="checkbox" name="wc_excitesms_enabled_notifications[order_status_changed]" value="1" <?php checked( 1, isset( $enabled_notifications['order_status_changed'] ) ? $enabled_notifications['order_status_changed'] : 0 ); ?>>
            Enable Order Status Changed Notification
        </label><br>
        <label>
            <input type="checkbox" name="wc_excitesms_enabled_notifications[order_cancelled]" value="1" <?php checked( 1, isset( $enabled_notifications['order_cancelled'] ) ? $enabled_notifications['order_cancelled'] : 0 ); ?>>
            Enable Order Cancelled Notification
        </label>
        <?php
    }

    public function send_sms_new_order( $order_id ) {
        $enabled_notifications = get_option( 'wc_excitesms_enabled_notifications', array() );

        if ( ! isset( $enabled_notifications['new_order'] ) || ! $enabled_notifications['new_order'] ) {
            return;
        }

        $order = wc_get_order( $order_id );
        $templates = get_option( 'wc_excitesms_templates', array() );
        $message = $templates['new_order'] ?? "Thank you for your order. Your order number is {order_number}.";
        $message = $this->replace_placeholders( $message, $order );

        // Send SMS to customer
        $this->send_sms( $order->get_billing_phone(), $message );

        // Send SMS to seller
        $seller_phone = get_option( 'wc_excitesms_seller_phone' );
        if ( $seller_phone ) {
            $seller_message = "New order received. Order number: {order_number}.";
            $seller_message = $this->replace_placeholders( $seller_message, $order );
            $this->send_sms( $seller_phone, $seller_message );
        }
    }

    public function send_sms_order_status_changed( $order_id, $old_status, $new_status ) {
        $enabled_notifications = get_option( 'wc_excitesms_enabled_notifications', array() );

        if ( ! isset( $enabled_notifications['order_status_changed'] ) || ! $enabled_notifications['order_status_changed'] ) {
            return;
        }

        $order = wc_get_order( $order_id );
        $templates = get_option( 'wc_excitesms_templates', array() );
        $message = $templates['order_status_changed'] ?? "Your order #{order_number} status changed to {new_status}.";
        $message = $this->replace_placeholders( $message, $order, $new_status );

        // Send SMS to customer
        $this->send_sms( $order->get_billing_phone(), $message );

        // Send SMS to seller
        $seller_phone = get_option( 'wc_excitesms_seller_phone' );
        if ( $seller_phone ) {
            $seller_message = "Order #{order_number} status changed to {new_status}.";
            $seller_message = $this->replace_placeholders( $seller_message, $order, $new_status );
            $this->send_sms( $seller_phone, $seller_message );
        }
    }

    public function send_sms_order_cancelled( $order_id ) {
        $enabled_notifications = get_option( 'wc_excitesms_enabled_notifications', array() );

        if ( ! isset( $enabled_notifications['order_cancelled'] ) || ! $enabled_notifications['order_cancelled'] ) {
            return;
        }

        $order = wc_get_order( $order_id );
        $templates = get_option( 'wc_excitesms_templates', array() );
        $message = $templates['order_cancelled'] ?? "Your order #{order_number} has been cancelled.";
        $message = $this->replace_placeholders( $message, $order );

        // Send SMS to customer
        $this->send_sms( $order->get_billing_phone(), $message );

        // Send SMS to seller
        $seller_phone = get_option( 'wc_excitesms_seller_phone' );
        if ( $seller_phone ) {
            $seller_message = "Order #{order_number} has been cancelled.";
            $seller_message = $this->replace_placeholders( $seller_message, $order );
            $this->send_sms( $seller_phone, $seller_message );
        }
    }

    private function replace_placeholders( $message, $order, $new_status = '' ) {
        $placeholders = array(
            '{order_number}' => $order->get_order_number(),
            '{order_date}'   => $order->get_date_created()->date('Y-m-d H:i:s'),
            '{billing_first_name}' => $order->get_billing_first_name(),
            '{billing_last_name}'  => $order->get_billing_last_name(),
            '{billing_email}'      => $order->get_billing_email(),
            '{new_status}'         => $new_status
        );

        foreach ( $placeholders as $placeholder => $value ) {
            $message = str_replace( $placeholder, $value, $message );
        }

        return $message;
    }

    private function send_sms( $recipient, $message ) {
        $api_key = get_option( 'wc_excitesms_api_key' );
        $sender_id = get_option( 'wc_excitesms_sender_id' );

        $args = array(
            'body' => json_encode( array(
                'recipient' => $recipient,
                'sender_id' => $sender_id,
                'type' => 'plain',
                'message' => $message,
            ) ),
            'headers' => array(
                'Accept' => 'application/json',
                'Authorization' => 'Bearer ' . $api_key,
                'Content-Type' => 'application/json',
            ),
        );

        $response = wp_remote_post( 'https://gateway.excitesms.com/api/v3/sms/send', $args );

        if ( is_wp_error( $response ) ) {
            error_log( 'ExciteSMS error: ' . $response->get_error_message() );
        } else {
            // Log the SMS sent
            $this->log_sms( $recipient, $message, $response );
        }
    }

    private function log_sms( $recipient, $message, $response ) {
        $log_entry = array(
            'recipient' => $recipient,
            'message' => $message,
            'response' => wp_remote_retrieve_body( $response ),
            'date' => current_time( 'mysql' )
        );

        $log = get_option( 'wc_excitesms_log', array() );
        $log[] = $log_entry;
        update_option( 'wc_excitesms_log', $log );
    }

    public function enqueue_admin_styles() {
        wp_enqueue_style( 'wc-excitesms-admin', plugin_dir_url( __FILE__ ) . 'css/admin.css' );
    }
}
?>
